"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.Server = exports.Client = void 0;
Object.defineProperty(exports, "SimpleMQBroker", {
  enumerable: true,
  get: function () {
    return _simpleMq.SimpleMQBroker;
  }
});
exports.default = void 0;
var _net = _interopRequireDefault(require("net"));
var _mqttPacket = _interopRequireDefault(require("mqtt-packet"));
var _events = require("events");
var _simpleMq = require("./simple-mq");
function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }
class Client extends _events.EventEmitter {
  constructor(socket, mqttOptions) {
    super();
    this._opts = mqttOptions;
    this.socket = socket;
    this.parser = _mqttPacket.default.parser(this._opts);
    this.parser.on('packet', packet => {
      this.emit('data', packet);
      this.emit(packet.cmd, packet);
    });
    this.parser.on('error', this.emit.bind(this, 'error'));
    this.socket.on('data', data => {
      this.parser.parse(data);
    });
    this.socket.on('error', this.emit.bind(this, 'error'));
    this.socket.on('close', this.emit.bind(this, 'close'));
  }
  setKeepAlive(keepalive) {
    this.socket.setKeepAlive(keepalive > 0, keepalive);
  }
  setProtocolVersion(version) {
    this._opts = Object.assign({}, this._opts, {
      protocolVersion: version
    });
    this.parser = _mqttPacket.default.parser(this._opts);
    this.parser.on('packet', packet => {
      this.emit('data', packet);
      this.emit(packet.cmd, packet);
    });
    this.parser.on('error', this.emit.bind(this, 'error'));
  }
  write(packet, cb) {
    this.socket.write(_mqttPacket.default.generate(packet, this._opts), undefined, cb);
  }
  end() {
    this.socket.end();
  }
  close() {
    this.socket.destroy();
  }
  connect(props, cb) {
    this.write(Object.assign({
      cmd: 'connect'
    }, props ?? {}), cb);
  }
  connack(props, cb) {
    this.write(Object.assign({
      cmd: 'connack'
    }, props ?? {}), cb);
  }
  publish(props, cb) {
    this.write(Object.assign({
      cmd: 'publish'
    }, props ?? {}), cb);
  }
  puback(props, cb) {
    this.write(Object.assign({
      cmd: 'puback'
    }, props ?? {}), cb);
  }
  pubrec(props, cb) {
    this.write(Object.assign({
      cmd: 'pubrec'
    }, props ?? {}), cb);
  }
  pubrel(props, cb) {
    this.write(Object.assign({
      cmd: 'pubrel'
    }, props ?? {}), cb);
  }
  pubcomp(props, cb) {
    this.write(Object.assign({
      cmd: 'pubcomp'
    }, props ?? {}), cb);
  }
  subscribe(props, cb) {
    this.write(Object.assign({
      cmd: 'subscribe'
    }, props ?? {}), cb);
  }
  suback(props, cb) {
    this.write(Object.assign({
      cmd: 'suback'
    }, props ?? {}), cb);
  }
  unsubscribe(props, cb) {
    this.write(Object.assign({
      cmd: 'unsubscribe'
    }, props ?? {}), cb);
  }
  unsuback(props, cb) {
    this.write(Object.assign({
      cmd: 'unsuback'
    }, props ?? {}), cb);
  }
  pingreq(props, cb) {
    this.write(Object.assign({
      cmd: 'pingreq'
    }, props ?? {}), cb);
  }
  pingresp(props, cb) {
    this.write(Object.assign({
      cmd: 'pingresp'
    }, props ?? {}), cb);
  }
  disconnect(props, cb) {
    this.write(Object.assign({
      cmd: 'disconnect'
    }, props ?? {}), cb);
  }
}
exports.Client = Client;
class Server extends _events.EventEmitter {
  constructor(opts) {
    super();
    this._opts = opts;
    this.server = _net.default.createServer(socket => {
      this.emit('connection', new Client(socket, this._opts));
    });
    this.server.on('error', this.emit.bind(this, 'error'));
    this.server.on('close', this.emit.bind(this, 'close'));
    this.server.on('listening', this.emit.bind(this, 'listening'));
  }
  listen(opts, callback) {
    this.server.listen(opts, callback);
  }
  close(callback) {
    this.server.close(callback);
  }
}
exports.Server = Server;
var _default = Server;
exports.default = _default;
//# sourceMappingURL=index.js.map