/// <reference types="node" />
/// <reference types="node" />
import type { QoS } from 'mqtt-packet';
import type { IPublishPacket } from 'mqtt-packet';
import type { Buffer } from 'buffer';
import { EventEmitter } from 'events';
import { Server, Client } from './';
export interface Options {
    authenticate?: (user?: string, pass?: Buffer) => Promise<boolean> | boolean;
    retryInterval?: number;
    keepalive?: number;
}
interface Message {
    topic: string;
    payload: string | Buffer;
}
export interface MQClientSession {
    pending: {
        [id: string]: Message;
    };
    subs: {
        [rule: string]: QoS;
    };
    tasks: {
        [id: number]: ReturnType<typeof setInterval>;
    };
    alive: boolean;
}
export declare class SimpleMQBroker extends EventEmitter {
    protected server: Server;
    protected clients: {
        [id: string]: Client;
    };
    protected sessions: {
        [id: string]: MQClientSession;
    };
    protected retryInterval: number;
    protected keepalive: number;
    protected authenticate?: (user?: string, pass?: Buffer) => Promise<boolean> | boolean;
    protected nextId: number;
    constructor(options?: Options);
    start(port?: number): void;
    stop(): void;
    protected handleClient(client: Client): void;
    protected processMessage(packet: Partial<IPublishPacket>): void;
    publish(topic: string, payload: string | Buffer, messageId: number | undefined): number;
    protected createPubTask(cId: string, messageId: number, topic: string, payload: string | Buffer, qos: QoS, dup?: boolean): void;
}
export default SimpleMQBroker;
//# sourceMappingURL=simple-mq.d.ts.map